///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  This software is distributed under the conditions and terms of the GNU   //
//  General Public License (GNU GPL).  A copy of the GNU GPL can be viewed   //
//  online at                                                                //
//                                                                           //
//       http://www.gnu.org/                                                 //
//                                                                           //
//  Although you are permitted to modify, recompile, and distribute this     //
//  source code or derivative works in accordance with the GNU GPL, you may  //
//  not remove or modify this notice.                                        //
//                                                                           //
//  Note that AlcPM requires components which may or may NOT be distributed  //
//  under the same license.  This includes, but is not necessarily limited   //
//  to:                                                                      //
//                                                                           //
//       1. a compatible operating system                                    //
//       2. a Java runtime environment                                       //
//       3. Lava, a Java library                                             //
//       4. Ping                                                             //
//                                                                           //
//  For additional licensing information, please contact the vendors of      //
//  these components.                                                        //
//                                                                           //
//  If you add features or fix errors in this source code, please consider   //
//  sharing your changes with Sharkysoft for inclusion in future releases.   //
//  Sharkysoft can be found on the web at                                    //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using AlcPM!                                               //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package sharky.app.alcpm;



import java.io.IOException;
import java.net.Socket;
import lava.io.AsciiInputStreamReader;
import lava.io.AsciiOutputStream;
import lava.io.IoCloser;
import lava.io.StreamParser;
import lava.io.UnlimitedPushbackReader;
import lava.thread.ThreadToolbox;



public class AlcatelRebooter
{



	private static final String TELNET_ENTER = "\r";



	private static final int TELNET_PORT = 23;



	private final String hostname;



	private UnlimitedPushbackReader in;



	private AsciiOutputStream out;



	AlcatelRebooter (String hostname)
	{
		this . hostname = hostname;
	}



	public boolean run ()
	{
		try
		{
			Socket socket = new Socket (hostname, TELNET_PORT);
			in = new UnlimitedPushbackReader (new AsciiInputStreamReader (socket . getInputStream ()));
			out = new AsciiOutputStream (socket . getOutputStream ());
			out . setLineSeparator (TELNET_ENTER);
			waitForUserPrompt ();
			pressEnter ();
			waitForCommandPrompt ();
			enterCommand ("system");
			waitForCommandPrompt ();
			enterCommand ("reboot");
			waitForConnectionToTimeOut ();
			IoCloser.close (out);
			IoCloser.close (in);
			socket . close ();
			return true;
		}
		catch (Exception e)
		{
			System.out . println (e);
		}
		return false;
	}



	private void waitForUserPrompt () throws IOException
	{
		if (! StreamParser.searchString (in, "User : ", 10, null))
			abort ();
	}



	private void waitForCommandPrompt () throws IOException
	{
		if (! StreamParser.searchString (in, "=>", 40 * 80, null))
			abort ();
	}



	private void enterCommand (String command) throws IOException
	{
		out . writeln (command);
		out . flush ();
	}



	private void pressEnter () throws IOException
	{
		out . writeln ();
		out . flush ();
	}



	private void waitForConnectionToTimeOut () throws IOException
	{
		int timeouts = 0;
		while (timeouts < 10)
		{
			if (! in . ready ())
			{
				ThreadToolbox.sleep (1000);
				++ timeouts;
				continue;
			}
			timeouts = 0;
			in . read ();
		}
	}



	private void dumpRest () throws IOException
	{
		while (true)
		{
			int c = in . read ();
			if (c < 0)
				break;
			System.out . print ((char) c);
		}
	}



	private static void abort () throws IOException
	{
		throw new IOException ("can't talk the talk");
	}



	public static void main (String[] args)
	{
		System.out . println (new AlcatelRebooter (args [0]) . run ());
	}



}



