///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  This software is distributed under the conditions and terms of the GNU   //
//  General Public License (GNU GPL).  A copy of the GNU GPL can be viewed   //
//  online at                                                                //
//                                                                           //
//       http://www.gnu.org/                                                 //
//                                                                           //
//  Although you are permitted to modify, recompile, and distribute this     //
//  source code or derivative works in accordance with the GNU GPL, you may  //
//  not remove or modify this notice.                                        //
//                                                                           //
//  Note that AlcPM requires components which may or may NOT be distributed  //
//  under the same license.  This includes, but is not necessarily limited   //
//  to:                                                                      //
//                                                                           //
//       1. a compatible operating system                                    //
//       2. a Java runtime environment                                       //
//       3. Lava, a Java library                                             //
//       4. Ping                                                             //
//                                                                           //
//  For additional licensing information, please contact the vendors of      //
//  these components.                                                        //
//                                                                           //
//  If you add features or fix errors in this source code, please consider   //
//  sharing your changes with Sharkysoft for inclusion in future releases.   //
//  Sharkysoft can be found on the web at                                    //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using AlcPM!                                               //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package sharky.app.alcpm;



import java.util.Calendar;
import java.util.GregorianCalendar;
import lava.io.IoToolbox;



public class Main
{



	public static void main (String[] args) throws Exception
	{
		if (args . length != 2)
		{
			showUsage ();
			return;
		}
		System.out . println ("Alcatel Pacemaker started at " + getTime () + ".");
		boolean lastup = false;
		while (true)
		{
			if (! lastup)
				System.out . print ("Checking network          at " + getTime () + "...");
			if (Ping.countReplies (args [0], 4) == 0)
			{
				if (! lastup)
					System.out . println ("error.");
				System.out . print ("Starting reboot           at " + getTime () + "...");
				if (new AlcatelRebooter (args [1]) . run ())
					System.out . println ("OK.");
				else
					System.out . println ("error.");
				Thread.sleep (120 * 1000);
				lastup = false;
			}
			else
			{
				if (! lastup)
					System.out . println ("OK.");
				lastup = true;
				Thread.sleep (30 * 1000);
			}
		}
	}



	private static void showUsage ()
	{
		String[] usage =
		{
			"Alcatel Pacemaker, by Charlton Rose",
			"Copyright (c) 2000-2002 Sharkysoft (sharkysoft.com).  All rights reserved.",
			"usage: alcatelpacemaker <ping-ip> <modem-ip>",
			"where",
			"\tping-ip is the address used to test connectivity",
			"\tmodem-ip is the address of the modem"
		};
		IoToolbox.printLines (usage);
	}



	private static String getTime ()
	{
		GregorianCalendar gc = new GregorianCalendar ();
		String year = "" + gc . get (Calendar.YEAR);
		String month = "0" + (gc . get (Calendar.MONTH) + 1);
		month = month . substring (month . length () - 2);
		String day = "0" + gc . get (Calendar.DAY_OF_MONTH);
		day = day . substring (day . length () - 2);
		String hour = "0" + gc . get (Calendar.HOUR);
		hour = hour . substring (hour . length () - 2);
		String minute = "0" + gc . get (Calendar.MINUTE);
		minute = minute . substring (minute . length () - 2);
		String second = "0" + gc . get (Calendar.SECOND);
		second = second . substring (second . length () - 2);
		return year + "." + month + "." + day + "." + hour + "." + minute + "." + second;
	}



}



